@@ -1,7 +1,5 @@
 # -*- coding: utf-8
-import os.path
-
-from pyboleto.data import BoletoData, custom_property
+from ..data import BoletoData, CustomProperty
 
 
 class BoletoBradesco(BoletoData):
@@ -9,12 +7,15 @@ class BoletoBradesco(BoletoData):
         Gera Dados necessários para criação de boleto para o banco Bradesco
     '''
 
-    def __init__(self, *args, **kwargs):
-        super(BoletoBradesco, self).__init__(*args, **kwargs)
+    nosso_numero = CustomProperty('nosso_numero', 11)
+    agencia_cedente = CustomProperty('agencia_cedente', 4)
+    conta_cedente = CustomProperty('conta_cedente', 7)
+
+    def __init__(self):
+        super(BoletoBradesco, self).__init__()
 
         self.codigo_banco = "237"
-        self.logo_image_path = os.path.dirname(__file__) + \
-            "/../media/logo_bancobradesco.jpg"
+        self.logo_image = "logo_bancobradesco.jpg"
 
     def format_nosso_numero(self):
         return "%s/%s-%s" % (
@@ -23,9 +24,6 @@ class BoletoBradesco(BoletoData):
             self.dv_nosso_numero
         )
 
-    # Nosso numero (sem dv) sao 11 digitos
-    nosso_numero = custom_property('nosso_numero', 11)
-
     @property
     def dv_nosso_numero(self):
         resto2 = self.modulo11(self.nosso_numero, 7, 1)
@@ -38,10 +36,6 @@ class BoletoBradesco(BoletoData):
             dv = digito
         return dv
 
-    agencia_cedente = custom_property('agencia_cedente', 4)
-
-    conta_cedente = custom_property('conta_cedente', 7)
-
     @property
     def campo_livre(self):
         content = "%4s%2s%11s%7s%1s" % (self.agencia_cedente.split('-')[0],
