@@ -1,31 +1,29 @@
 #-*- coding: utf-8 -*-
-import os.path
-
-from pyboleto.data import BoletoData, custom_property
+from ..data import BoletoData, CustomProperty
 
 
 class BoletoCaixa(BoletoData):
     '''
         Gera Dados necessários para criação de boleto para o banco Caixa
         Economica Federal
+
     '''
 
-    conta_cedente = custom_property('conta_cedente', 11)
-
+    conta_cedente = CustomProperty('conta_cedente', 11)
     '''
         Este numero tem o inicio fixo
         Carteira SR: 80, 81 ou 82
         Carteira CR: 90 (Confirmar com gerente qual usar)
-    '''
-    nosso_numero = custom_property('nosso_numero', 10)
 
-    def __init__(self, *args, **kwargs):
-        super(BoletoCaixa, self).__init__(*args, **kwargs)
+    '''
+    nosso_numero = CustomProperty('nosso_numero', 10)
+
+    def __init__(self):
+        super(BoletoCaixa, self).__init__()
 
         self.codigo_banco = "104"
         self.local_pagamento = "Preferencialmente nas Casas Lotéricas e Agências da Caixa"
-        self.logo_image_path = os.path.dirname(__file__) + \
-            "/../media/logo_bancocaixa.jpg"
+        self.logo_image = "logo_bancocaixa.jpg"
 
     @property
     def dv_nosso_numero(self):
@@ -45,4 +43,4 @@ class BoletoCaixa(BoletoData):
         return content
 
     def format_nosso_numero(self):
-        return self._nosso_numero + '-' + str(self.dv_nosso_numero)
+        return self.nosso_numero + '-' + str(self.dv_nosso_numero)
