@@ -4,7 +4,7 @@ import datetime
 
 from pyboleto.bank.real import BoletoReal
 
-from testutils import BoletoTestCase
+from .testutils import BoletoTestCase
 
 
 class TestBancoReal(BoletoTestCase):
@@ -21,9 +21,6 @@ class TestBancoReal(BoletoTestCase):
         d.numero_documento = '123'
         self.dados = d
 
-    def test_render(self):
-        self.check_pdf_rendering('real', self.dados)
-
     def test_linha_digitavel(self):
         self.assertEqual(self.dados.linha_digitavel,
             '35690.53154 70585.390001 00000.001230 8 48690000035500'
